
% declare endogenous variables (assume K=16)

%% set the number of sectors
@#define secnum = 16


% var ey pi y R;            % variables (aggregate)
var ppi y R;            % variables (aggregate)

% variables (sectoral)
@#for i in 1:secnum   
     var pi@{i}
          pr@{i}
          a@{i}
          mu@{i};
@#endfor

% variables with data (aggregate)
var Dy;		  

% variables with data (sectoral)
@#for i in 1:secnum   
     var Dpi@{i}
          Da@{i};
@#endfor


% declare exogenous variables (innovations to the shocks)

varexo vy;

@#for i in 1:secnum
   varexo va@{i}
             vmu@{i};
@#endfor


% declare parameters

parameters sigma bet varphi theta eta;
@#for i in 1:secnum
   parameters n@{i}
	     alph@{i} 
	     rhoa@{i}
 	     rhomu@{i}; 
@#endfor


%% parameter values
sigma = 2;
bet   = 0.99; 
varphi = 1;
eta     = 3;
theta   = 6;

% load .mat files with parameter values
load calvo.mat
load size.mat

% Sectoral parameter values (alpha and n)
@# for i in 1:secnum
   set_param_value('alph@{i}', calvo(@{i}));
@# endfor

@# for i in 1:secnum
   set_param_value('n@{i}', size(@{i}));
@# endfor


 @#for i in 1:secnum
    rhoa@{i} = 0.9;
 @#endfor

 @#for i in 1:secnum
    rhomu@{i} = 0.9;
 @#endfor

%% model (LOG-LINEAR SYSTEM)

model(linear);


% compound parameters
@# for i in 1:secnum
   #kapp@{i} = (1-alph@{i})*(1-alph@{i}*bet)/alph@{i}* 1/(1+theta*varphi);
@#endfor


% equilibrium equations

   y = y(+1) - 1/sigma*(R - ppi(+1));

   0 = 
         @#for i in 1:secnum
       	 +n@{i}*pr@{i}
         @#endfor
	;

%   ppi = 
%         @#for i in 1:secnum
%       	 +n@{i}*pi@{i}
%         @#endfor
%	;

   @#for i in 1:secnum
	pi@{i} = bet * pi@{i}(+1) + kapp@{i}*( (sigma+varphi)*y - (1 + varphi*eta)*pr@{i} - (1+varphi)*a@{i} )  - mu@{i} ;                                                % sectoral Phillips curve
	pi@{i} - ppi = pr@{i} - pr@{i}(-1);   % identity equation for relative price pr
   @#endfor

   ppi + y - y(-1) = vy; %%%	   % monetary policy


% shock processes (productivity and cost-push shocks)

   @#for i in 1:secnum
	a@{i} = rhoa@{i}*a@{i}(-1) + va@{i};
	mu@{i} = rhomu@{i}*mu@{i}(-1) + vmu@{i};
   @#endfor

 %  ey    = vy;    %%%

% measurement equations
   Dy    = y;

   @#for i in 1:secnum
	Dpi@{i} = pi@{i};
	Da@{i} = a@{i};
   @#endfor

end;

% shocks;
% var vphi;  	stderr 2/100;
% var vlamt;  stderr 0.5/100;
% var vz;  	stderr 2/100;
% var vg; 	stderr 2/100;
% var veR;  	stderr 0.5/100;
% end;

% set prior distributions for the parameters

estimated_params;

@#for i in 1:secnum
rhomu@{i},	0.9,	1e-8,	100,		beta_pdf, 		0.7,	0.15;
@#endfor

@#for i in 1:secnum
rhoa@{i}, 		0.9,	1e-8,	100,		beta_pdf, 		0.7,	0.15;
@#endfor

@#for i in 1:secnum 
stderr vmu@{i},	 	2/100,  1e-8,	100,	    inv_gamma_pdf,  2/100,  0.5;		
@#endfor

@#for i in 1:secnum 
stderr va@{i}, 		2/100,  1e-8,	100,	    inv_gamma_pdf,  2/100,  0.5;		
@#endfor

stderr vy, 	 	2/100,  1e-8,	100,	    inv_gamma_pdf,  2/100,  0.5;	

end;

steady;
check;
stoch_simul;

% declare observable variables

varobs  Dy
@#for i in 1:secnum
      Dpi@{i} Da@{i}
@#endfor
    ;

% identification(parameter_set=prior_mean,advanced=1);

estimation(datafile=data_empreq_short_hp,mode_compute=6,mode_check,order=1,mh_replic=20000,mh_nblocks=2,mh_jscale=0.25,mh_drop=0.33);

%estimation(datafile=data_empreq_short,mode_file= paper_bayesian_mode, mode_compute=6,posterior_sampling_method='tailored_random_block_metropolis_hastings',order=1,mh_replic=30000,mh_nblocks=1,mh_jscale=0.25,mh_drop=0.33);

